@@ -14,7 +14,7 @@ def data_dict():
         'A': 1,
         'B': 'B',
         'C': None,
-        'D': datetime(2023, 7, 25, 1, 2, 3, tzinfo=UTC),
+        'D': datetime(2023, 7, 25, 1, 2, 3),
         'E': date(2023, 7, 24),
         'F': Decimal('1.23'),
     }
@@ -32,9 +32,7 @@ class TestData:
 
 @pytest.fixture
 def data_dataclass():
-    return TestData(
-        a=1, b='B', c=None, d=datetime(2023, 7, 25, 1, 2, 3, tzinfo=UTC), e=date(2023, 7, 24), f=Decimal('1.23')
-    )
+    return TestData(a=1, b='B', c=None, d=datetime(2023, 7, 25, 1, 2, 3), e=date(2023, 7, 24), f=Decimal('1.23'))
 
 
 class SubStruc(msgspec.Struct):
